@@ -25,6 +25,7 @@
 #include <math.h>
 #include <glib/gi18n.h>
 #include <gdk/gdk.h>
+#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <gio/gio.h>
@@ -322,9 +323,22 @@ static gboolean
 grab_keyboard_on_window (GdkWindow *window,
 			 guint32    activate_time)
 {
+	GdkDisplay *display;
+	GdkSeat *seat;
 	GdkGrabStatus status;
 
-	status = gdk_keyboard_grab (window, TRUE, activate_time);
+	display = gdk_window_get_display (window);
+	seat = gdk_display_get_default_seat (display);
+
+	status = gdk_seat_grab (seat,
+	                        window,
+	                        GDK_SEAT_CAPABILITY_KEYBOARD,
+	                        TRUE,
+	                        NULL,
+	                        NULL,
+	                        NULL,
+	                        NULL);
+
 	if (status == GDK_GRAB_SUCCESS) {
 		return TRUE;
 	}
@@ -769,18 +783,14 @@ create_secondary_break_windows (void)
 	GdkDisplay *display;
 	GdkScreen  *screen;
 	GtkWidget  *window;
-	gint        i;
 	GList      *windows = NULL;
 
 	display = gdk_display_get_default ();
 
-	for (i = 0; i < gdk_display_get_n_screens (display); i++) {
-		screen = gdk_display_get_screen (display, i);
+	screen = gdk_display_get_default_screen (display);
 
-		if (screen == gdk_screen_get_default ()) {
-			/* Handled by DrwBreakWindow. */
-			continue;
-		}
+	if (screen != gdk_screen_get_default ()) {
+		/* Handled by DrwBreakWindow. */
 
 		window = gtk_window_new (GTK_WINDOW_POPUP);
 
@@ -789,8 +799,8 @@ create_secondary_break_windows (void)
 		gtk_window_set_screen (GTK_WINDOW (window), screen);
 
 		gtk_window_set_default_size (GTK_WINDOW (window),
-					     gdk_screen_get_width (screen),
-					     gdk_screen_get_height (screen));
+					     WidthOfScreen (gdk_x11_screen_get_xscreen (screen)),
+					     HeightOfScreen (gdk_x11_screen_get_xscreen (screen)));
 
 		gtk_widget_set_app_paintable (GTK_WIDGET (window), TRUE);
 		drw_setup_background (GTK_WIDGET (window));
